<?php


namespace OrganizationsManagement\Repository;


use Doctrine\ORM\EntityManager;
use OrganizationsManagement\Util\InstanceProvider;
use Teknisa\Model\Traits\TQuery;

class Notice
{
    use TQuery;
    /**
     * @var EntityManager
     */
    private $entityManager;

    /**
     * Notice constructor.
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    // TO_CHAR(SYSDATE, 'DD/MM/YYYY')

    public function getNoticeRecords()
    {
        $query = <<<SQL
        SELECT NRINFECOMMERCE,
               DSTITULOINF,
               TXCONTEUDOINF,
               IDNOTIFICACAO,
               TO_CHAR(DTINFORMARIVI, 'DD/MM/YYYY') AS DTINFORMARIVI,
               TO_CHAR(DTEXPIRAINFO, 'DD/MM/YYYY') AS DTEXPIRAINFO,
               TO_CHAR(DTINCLUSAO, 'DD/MM/YYYY') AS DTINCLUSAO,
               TO_CHAR(DTULTATU, 'DD/MM/YYYY') AS DTULTATU,
               IDATIVO
          FROM INFORMATIVOECOMMERCE
SQL;

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query);
    }

    public function insertNotice($data)
    {
        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        try {
            $query = <<<SQL
            INSERT
              INTO INFORMATIVOECOMMERCE
                   (NRINFECOMMERCE,
                   DSTITULOINF,
                   TXCONTEUDOINF,
                   IDNOTIFICACAO,
                   DTINFORMARIVI,
                   DTEXPIRAINFO,
                   DTINCLUSAO,
                   DTULTATU,
                   IDATIVO)
            VALUES (:ID,
                   :TITULO,
                   :CONTEUDO,
                   :TIPO,
                   TRUNC(CAST(:DATAINICIO AS DATE)),
                   TRUNC(CAST(:DATATERMINO AS DATE)),
                   TRUNC(CAST(SYSDATE AS DATE)),
                   TRUNC(CAST(SYSDATE AS DATE)),
                   :ATIVO)
SQL;
            $params = array(
                'ID' => $data['id'],
                'TITULO' => $data['title'],
                'CONTEUDO' => $data['content'],
                'TIPO' => $data['type'],
                'DATAINICIO' => $data['dateBegin'],
                'DATATERMINO' => $data['dateEnd'],
                'ATIVO' => $data['active']
            );

            $connection->executeQuery($query, $params);
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw new \Exception($e->getMessage());
        }
    }

    public function deleteNotice($ids)
    {

        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        try {
            foreach ($ids as $id) {
                $query = <<<SQL
                DELETE
                  FROM INFORMATIVOECOMOPER
                 WHERE NRINFECOMMERCE = ?
SQL;
                $connection->executeQuery($query, array($id));

                $query = <<<SQL
                DELETE
                  FROM INFORMATIVOECOMMERCE
                 WHERE NRINFECOMMERCE = ?
SQL;
                $connection->executeQuery($query, array($id));
            }
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw new \Exception($e->getMessage());
        }
    }

    public function updateNotice($data)
    {
        $connection = InstanceProvider::getEntityManager()->getConnection();
        $connection->beginTransaction();
        try {
            foreach ($data as $item) {
                $query = <<<SQL
                 UPDATE INFORMATIVOECOMMERCE 
                    SET DSTITULOINF = :TITULO, 
                        TXCONTEUDOINF = :CONTEUDO, 
                        IDNOTIFICACAO = :TIPO, 
                        DTINFORMARIVI = TRUNC(CAST(:DATAINICIO AS DATE)),
                        DTEXPIRAINFO = TRUNC(CAST(:DATATERMINO AS DATE)), 
                        DTULTATU = TRUNC(CAST(SYSDATE AS DATE)),
                        IDATIVO = :ATIVO 
                  WHERE NRINFECOMMERCE = :ID
SQL;
                $params = array(
                    'ID' => $item['id'],
                    'TITULO' => $item['title'],
                    'CONTEUDO' => $item['content'],
                    'TIPO' => $item['type'],
                    'DATAINICIO' => $item['dateBegin'],
                    'DATATERMINO' => $item['dateEnd'],
                    'ATIVO' => $item['active']
                );
                $connection->executeQuery($query, $params);
            }
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw new \Exception($e->getMessage());
        }
    }
}
