import { Http, Router } from '@zeedhi/core';
import { DialogService, Modal, ModalService, AlertService, TextInput } from '@zeedhi/common';
import { OMInstance } from '@/services/OMInstance';
import { OmDialogService } from '@/services/OmDialogService';
import Messages from '@/services/Messages';

export class ClientsByOperatorController {
    public CliByOpGridDisabled = true;

    public cdoperadorToModal = '';

    public fantasyNameToModal = '';

    // *** OPERATORS GRID ***

    public goToOpByCli() {
        Router.push('/operadores-por-cliente');
    }

    public async rowClickOperatorsGrid(params: any) {
        if (!params.component.editing) {
            try {
                this.CliByOpGridDisabled = true;
                const cliByOpGrid = OMInstance.getInstanceTekGrid('ClientsByOperatorGridCliByOp');
                cliByOpGrid.datasource.filter.CDOPERADOR = params.row.CDOPERADOR;
                this.clearSelectedRowsCliByOpGrid();
                await cliByOpGrid.datasource.get();
                this.cdoperadorToModal = params.row.CDOPERADOR;
                this.fantasyNameToModal = params.row.NMOPERADOR;
                this.CliByOpGridDisabled = false;
            } catch (e) {
                OmDialogService.showErrorBackend(e);
                this.CliByOpGridDisabled = true;
            }
        }
    }

    public async saveEditionsOperatorsGrid(params: any) {
        params.event.preventDefault();
        try {
            const operadores = { operadores: params.component.getEditedRows() };
            await Http.post('/operadorMaster', operadores);
            AlertService.show({
                name: 'successSaveModal',
                color: 'success',
                showDismiss: true,
                timeout: 3000,
                top: true,
                right: true,
                text: 'Salvo com sucesso!',
            });
            params.component.editing = false;
			params.component.datasource.get();
			this.clearCliByOpGrid();
        } catch (e) {
			OmDialogService.showErrorBackend(e);
		}
    }

    // *** CLIENT BY OPERATOR GRID (CliByOp) ***

    public selectedRowsCliByOpGrid: any;

    public async reloadCliByOpGrid() {
        const cliByOpGrid = OMInstance.getInstanceTekGrid('ClientsByOperatorGridCliByOp');
        try {
            await cliByOpGrid.datasource.get();
        } catch (e) {
			OmDialogService.showErrorBackend(e);
		}
    }

    public deleteRowCliByOpGrid(params: any) {
        params.event.preventDefault();
        this.selectedRowsCliByOpGrid = params.component;
        DialogService.show({
            name: 'delete_dialog',
            type: 'error',
            title: 'Operação de Deleção',
            text: Messages.DELETE_DEFAULT,
            buttons: [
                { name: 'yesButton', component: 'ZdButton', label: 'Sim', events: this.dialogContinue, outline: true },
                { name: 'noButton', component: 'ZdButton', label: 'Não', events: this.dialogHide },
            ],
        });
    }

    private dialogContinue: any = {
        click: async () => {
            try {
                await Http.delete('/relacionarClientesComOperador', { data: this.selectedRowsCliByOpGrid.selectedRows });
                AlertService.show({
                    name: 'successSaveModal',
                    color: 'success',
                    showDismiss: true,
                    timeout: 3000,
                    top: true,
                    right: true,
                    text: 'Registro(s) excluído(s) com sucesso!',
                });
                this.clearSelectedRowsCliByOpGrid();
                this.selectedRowsCliByOpGrid.datasource.get();
                DialogService.hide();
            } catch (e) {
                OmDialogService.showErrorBackend(e);
            }
        },
    };

    private dialogHide: any = {
        click: () => DialogService.hide(),
    };

    private async clearCliByOpGrid() {
        this.clearSelectedRowsCliByOpGrid();
        this.CliByOpGridDisabled = true;
        const cliByOpGrid = OMInstance.getInstanceTekGrid('ClientsByOperatorGridCliByOp');
        cliByOpGrid.datasource.filter.CDOPERADOR = '';
        try {
            await cliByOpGrid.datasource.get();
        } catch (e) {
            OmDialogService.showErrorBackend(e);
        }
    }

    private clearSelectedRowsCliByOpGrid() {
        const cliByOpGrid = OMInstance.getInstanceTekGrid('ClientsByOperatorGridCliByOp');
        cliByOpGrid.selectedRows = [];
    }

    // MODAL ADD CLIENTES POR OPERADOR

    public relationshipModal!: Modal;

    public priorityInputDisabled = true;

    public async onCreatedCliByOpGrid() {
        this.relationshipModal = await ModalService.createFromJson('clientsByOperator/modal/clientsByOperatorModal', true);
    }

    public onDestroyCliByOpGrid() {
        this.relationshipModal?.destroy();
    }

    public modalCliByOpGrid: any;

    public async addNewRelationCliByOpGrid() {
        await this.relationshipModal.show();
        this.modalCliByOpGrid = await OMInstance.getInstanceTekGrid('gridModalCliByOp');
        this.modalCliByOpGrid.datasource.filter.CDOPERADOR = await this.cdoperadorToModal;
        try {
            await this.modalCliByOpGrid.datasource.get();
        } catch (e) {
            OmDialogService.showErrorBackend(e);
        }
        this.operatorTypeChangeEvent();
    }

    public backButtonModalCliByOp() {
        this.relationshipModal.hide();
    }

    public async saveModalCliByOp() {
        const gridModalinstance = OMInstance.getInstanceTekGrid('gridModalCliByOp');
        const formModalInstance = OMInstance.getInstanceZdForm('formModalGridCliByOp');
        if (gridModalinstance.selectedRows.length > 0) {
            const formValidation = formModalInstance.validate();
            if (formValidation) {
                formModalInstance.resetValidation();
                const sendObject = {
                    cdoperador: this.cdoperadorToModal,
                    idtpoperclie: formModalInstance.value.selectOperatorTypeModalGridCliByOp,
                    nrpriopercli: formModalInstance.value.inputPriorityTypeModalGridCliByOp,
                    clientes: gridModalinstance.selectedRows,
                };
                try {
                    await Http.post('/relacionarClientesComOperador', sendObject);
                    AlertService.show({
                        name: 'successSaveModal',
                        color: 'success',
                        showDismiss: true,
                        timeout: 3000,
                        top: true,
                        right: true,
                        text: 'Salvo com sucesso!',
                    });
                    gridModalinstance.selectedRows = [];
                    this.reloadCliByOpGrid();
                    this.relationshipModal.hide();
                } catch (e) {
                    OmDialogService.showErrorBackend(e);
                }
            }
        } else {
            AlertService.show({
                name: 'noSelectedRow',
                color: 'error',
                showDismiss: true,
                timeout: 3000,
                top: true,
                right: true,
                text: 'Selecione pelo menos um cliente para salvar!',
            });
        }
    }

    public operatorTypeChangeEvent() {
        const formModalInstance = OMInstance.getInstanceZdForm('formModalGridCliByOp');
        const priorityTypeInstance = formModalInstance.getChildInstance<TextInput>('inputPriorityTypeModalGridCliByOp');
        if (formModalInstance.value.selectOperatorTypeModalGridCliByOp === 'R') {
            this.priorityInputDisabled = false;
            priorityTypeInstance.addValidation('required');
        } else {
            this.priorityInputDisabled = true;
            priorityTypeInstance.value = '';
            priorityTypeInstance.removeValidation('required');
        }
    }
}
